@@ -5,8 +5,8 @@ use Pcore::Ext;
 use Pcore::Util::Data qw[to_json];
 use Pcore::Util::Scalar qw[is_plain_arrayref];
 
-has ext_app   => ( required => 1 );     # name of the linked application, required
-has ext_title => 'ExtJS Application';
+has ext_package => ( required => 1 );     # name of the linked application, required
+has ext_title   => 'ExtJS Application';
 
 has _index => ();
 
@@ -16,17 +16,18 @@ sub BUILD ( $self, $args ) {
     # init Ext
     my $ext = $self->{app}->{ext} //= Pcore::Ext->new( app => $self->{app} );
 
-    # TODO return if in production mode and app is absolute, eg: Module::Path::App
-    return if index( $self->{ext_app}, '::' ) != -1 && !$self->{app}->{devel};
-
-    # expand app namespace, if it is relative to the current dist
-    my $ns = index( $self->{ext_app}, '::' ) == -1 ? ref( $self->{app} ) . '::Ext::' . $self->{ext_app} : $self->{ext_app};
+    # expand relative package name
+    if ( index( $self->{ext_package}, '::' ) == -1 ) {
+        $self->{ext_package} = ref( $self->{app} ) . '::Ext::' . $self->{ext_package};
+    }
+    else {
+        return if !P->class->find( $self->{ext_package} );
+    }
 
     $ext->create_app(
-        $self->{ext_app},
-        {   namespace => $ns,
-            cdn       => undef,    # maybe InstanceOf['Pcore::CDN']
-            prefixes  => {
+        $self->{ext_package},
+        {   cdn      => undef,    # maybe InstanceOf['Pcore::CDN']
+            prefixes => {
                 pcore => undef,
                 dist  => undef,
                 app   => undef,
@@ -40,7 +41,7 @@ sub BUILD ( $self, $args ) {
     return;
 }
 
-sub _get_app ($self) { return $self->{app}->{ext}->{ext_app}->{ $self->{ext_app} } }
+sub _get_app ($self) { return $self->{app}->{ext}->{ext_app}->{ $self->{ext_package} } }
 
 around run => sub ( $orig, $self, $req ) {
     return $req->return_xxx(404) if !$self->_get_app;
@@ -64,7 +65,7 @@ sub _return_index ( $self, $req ) {
 
         # app
         # push $resources->@*, $cdn->get_script_tag( $self->get_abs_path('app.js') );
-        push $resources->@*, $cdn->get_script_tag( $cdn->("/app/$self->{ext_app}/app.js") );
+        push $resources->@*, $cdn->get_script_tag( $cdn->("/app/$app->{id}/app.js") );
 
         # generate HTML tmpl
         $self->{_index} = \P->text->encode_utf8(
@@ -91,7 +92,7 @@ sub _return_index ( $self, $req ) {
 ## +------+----------------------+----------------------------------------------------------------------------------------------------------------+
 ## | Sev. | Lines                | Policy                                                                                                         |
 ## |======+======================+================================================================================================================|
-## |    3 | 63                   | ValuesAndExpressions::ProhibitInterpolationOfLiterals - Useless interpolation of literal string                |
+## |    3 | 64                   | ValuesAndExpressions::ProhibitInterpolationOfLiterals - Useless interpolation of literal string                |
 ## +------+----------------------+----------------------------------------------------------------------------------------------------------------+
 ##
 ## -----SOURCE FILTER LOG END-----
