@@ -176,7 +176,7 @@ sub EXT_version : Extend('Ext.Panel') {
         items => [
             {   xtype => 'component',
                 bind  => '{session.version}',
-                style => 'color:grey;',
+                style => 'color:grey;text-align:right;',
             },
         ],
     };
